/// <reference types="node" />
import type { CompileError } from '@astrojs/parser';
import { Writable } from 'stream';
export declare const defaultLogDestination: Writable;
interface LogWritable<T> extends Writable {
    write: (chunk: T) => boolean;
}
export declare type LoggerLevel = 'debug' | 'info' | 'warn' | 'error' | 'silent';
export declare type LoggerEvent = 'info' | 'warn' | 'error';
export interface LogOptions {
    dest?: LogWritable<LogMessage>;
    level?: LoggerLevel;
}
export declare const defaultLogOptions: Required<LogOptions>;
export interface LogMessage {
    type: string | null;
    level: LoggerLevel;
    message: string;
    args: Array<any>;
}
export declare const levels: Record<LoggerLevel, number>;
export declare function enableVerboseLogging(): void;
/** Full logging API */
export declare function log(opts: LogOptions | undefined, level: LoggerLevel, type: string | null, ...args: Array<any>): void;
/**
 * Emit a message only shown in debug mode.
 * Astro (along with many of its dependencies) uses the `debug` package for debug logging.
 * You can enable these logs with the `DEBUG=astro:*` environment variable.
 * More info https://github.com/debug-js/debug#environment-variables
 */
export declare function debug(type: string, ...messages: Array<any>): any;
/** Emit a user-facing message. Useful for UI and other console messages. */
export declare function info(opts: LogOptions, type: string | null, ...messages: Array<any>): void;
/** Emit a warning message. Useful for high-priority messages that aren't necessarily errors. */
export declare function warn(opts: LogOptions, type: string | null, ...messages: Array<any>): void;
/** Emit a error message, Useful when Astro can't recover from some error. */
export declare function error(opts: LogOptions, type: string | null, ...messages: Array<any>): void;
declare type LogFn = typeof info | typeof warn | typeof error;
export declare function table(opts: LogOptions, columns: number[]): (logFn: LogFn, ...input: Array<any>) => void;
/** Pretty format error for display */
export declare function parseError(opts: LogOptions, err: CompileError): void;
export declare const logger: {
    info: (type: string | null, ...messages: any[]) => void;
    warn: (type: string | null, ...messages: any[]) => void;
    error: (type: string | null, ...messages: any[]) => void;
};
export declare let defaultLogLevel: LoggerLevel;
/** Print out a timer message for debug() */
export declare function timerMessage(message: string, startTime?: number): string;
export {};
